{ inputs, config, pkgs, ... }:
{
    imports = [
        (import ./common.nix { inherit inputs config pkgs; })
        (import ../hyprland { inherit inputs pkgs; })
        (import ../ags { inherit inputs config pkgs; })
        ../rofi
        ../alacritty
        ../kitty
        ../firefox
        ../ssh
        ../mpv
    ];

    home.packages = with pkgs; [
        onlyoffice-bin
        telegram-desktop
        webcord
        iwgtk
        element-desktop-wayland
        evince
        loupe
        gimp
        obs-studio
        inkscape
        gnome-calendar
        file-roller
        zip
        heroic
        cmake
        jellyfin-media-player
        chromium
        nmap
        arp-scan
        virt-manager
        wol
        dig
        file
        zip
        yubioath-flutter
        obsidian
    ];

    services.kdeconnect = {
        enable = true;
        package = pkgs.kdePackages.kdeconnect-kde;
        indicator = true;
    };

    programs.thunderbird = {
        enable = true;
        profiles.default.isDefault = true;
    };

    gtk = {
        enable = true;
        theme = {
            package = pkgs.gnome-themes-extra;
            name = "Adwaita-dark";
        };
        iconTheme = {
            name = "Papirus";
            package = pkgs.papirus-icon-theme;
        };
    };

    home.pointerCursor = {
        gtk.enable = true;
        name = "Adwaita";
        size = 28;
        package = pkgs.adwaita-icon-theme;
    };

    services.cliphist = { enable = true; };

    xdg.mimeApps = {
        enable = true;
        defaultApplications = {
            "x-scheme-handler/mailto" = "userapp-Thunderbird-7GETV2.desktop";
            "x-scheme-handler/mid" = "userapp-Thunderbird-7GETV2.desktop";
            "message/rfc822" = "userapp-Thunderbird-7GETV2.desktop";
            "application/pdf" = "org.gnome.Evince.desktop";
            "x-scheme-handler/tg" = "org.telegram.desktop.desktop";
            "video/*" = "mpv.desktop";
            "audio/*" = "mpv.desktop";
            "image/jpeg" = "org.gnome.Loupe.desktop";
            "image/png" = "org.gnome.Loupe.desktop";
        };
        associations.added = {
            "x-scheme-handler/tg" = "org.telegram.desktop.desktop";
            "x-scheme-handler/mailto" = "userapp-Thunderbird-7GETV2.desktop";
            "x-scheme-handler/mid" = "userapp-Thunderbird-7GETV2.desktop";
            "image/jpeg" = "org.gnome.Loupe.desktop";
            "image/png" = "org.gnome.Loupe.desktop";
        };
    };
}
